#ifndef NT2_INCLUDE_CONSTANTS_NBMANTISSABITS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_NBMANTISSABITS_HPP_INCLUDED

#include <nt2/constant/include/constants/nbmantissabits.hpp>

#endif
